==> pygame-light2d-1.0.0.tar.gz: pygame-light2d-1.0.0/README.md <==
# Pygame Light 2D
This module provides fast 2D dynamic lighting for `pygame`. 

https://github.com/MarkelZ/pygame-light2d/assets/60424316/a8d1322b-ac05-47d4-8b04-2786f0d3c96a

## Dependencies

- `Python` version >= 3.10
- `numpy` >= 1.24.1
- `pygame` >= 2.3.0
- `moderngl` >= 5.8.2
- `PyOpenGL` >= 3.1.6

Earlier versions of these packages might also work, although they haven't been extensively tested.

## Installation

Firstly, ensure that all the required dependencies are installed.

Then, run the following command:

```sh
python3 -m pip install pygame-light2d
```

To verify correct installation, open a Python terminal and import the module:

```py
import pygame_light2d
```

If there are no errors, the installation was successful!

## Getting started

To learn how to create a simple game with lighting effects using `pygame-light2d`, check out the [`Getting started`](https://github.com/MarkelZ/pygame-light2d/wiki/Getting-Started) page on the wiki.

## Documentation

### Using the API

For detailed explanations of the API, please refer to the [API Reference](https://github.com/MarkelZ/pygame-light2d/wiki).

### Using `pygame-light2d` in an existing project

If you're looking to incorporate `pygame-ligth2d` into an existing project, we recommend starting with our guide on [Adding lights to an existing project](https://github.com/MarkelZ/pygame-light2d/wiki/Adding-lights-to-an-existing-project).

## Contributing

We greatly appreciate and encourage contributions from the community! 

Please take a look at the [Contributing](https://github.com/MarkelZ/pygame-light2d/wiki/Contributing) page on the wiki for details on how to contribute to the project.


## License

This code is licensed under the terms of the MIT license.

==> pygame-light2d-1.1.0.tar.gz: pygame-light2d-1.1.0/README.md <==
# Pygame Light 2D
This module provides fast 2D dynamic lighting for `pygame`. 

https://github.com/MarkelZ/pygame-light2d/assets/60424316/a8d1322b-ac05-47d4-8b04-2786f0d3c96a

## Dependencies

- `Python` version >= 3.10
- `numpy` >= 1.24.1
- `pygame` >= 2.3.0
- `moderngl` >= 5.8.2
- `PyOpenGL` >= 3.1.6

## Installation

Firstly, ensure that the correct Python version is installed.

Then, run the following command:

```sh
python3 -m pip install pygame-light2d
```

To verify correct installation, open a Python terminal and import the module:

```py
import pygame_light2d
```

If there are no errors, the installation was successful!

## Getting started

To learn how to create a simple game with lighting effects using `pygame-light2d`, check out the [`Getting started`](https://github.com/MarkelZ/pygame-light2d/wiki/Getting-Started) page on the wiki.

## Documentation

### Using the API

For detailed explanations of the API, please refer to the [API Reference](https://github.com/MarkelZ/pygame-light2d/wiki/API-Reference).

### Using `pygame-light2d` in an existing project

If you're looking to incorporate `pygame-ligth2d` into an existing project, we recommend starting with our guide on [Adding lights to an existing project](https://github.com/MarkelZ/pygame-light2d/wiki/Adding-lights-to-an-existing-project).

## Frequently Asked Questions

For frequently asked questions check out [FAQ](https://github.com/MarkelZ/pygame-light2d/wiki/FAQ).

## Contributing

We greatly appreciate and encourage contributions from the community! 

Please take a look at the [Contributing](https://github.com/MarkelZ/pygame-light2d/wiki/Contributing) page on the wiki for details on how to contribute to the project.

## License

This code is licensed under the terms of the MIT license.
